@@ -33,9 +33,15 @@ from trading_backend.exchanges.ftx import (
     FTX
 )
 
+from trading_backend.exchanges import gateio
+from trading_backend.exchanges.gateio import (
+    GateIO
+)
+
 __all__ = [
     "Exchange",
     "Binance",
     "OKEx",
     "FTX",
+    "GateIO",
 ]
